@@ -46,6 +46,18 @@ class TestSimple(unittest.TestCase):
         map(dq.put, range(3))
         self.assertEqual((0, 3), dq.size())
 
+    def testSetWidthToZeroAfterInitiallyNonZero(self):
+        """
+        Make sure that a queue whose width is initially non-zero and which
+        is then set to zero width does not then begin to process any added
+        jobs.
+        """
+        dq = ResizableDispatchQueue(None, 3)
+        dq.width = 0
+        dq.put('aaa')
+        dq.put('bbb')
+        self.assertEqual((0, 2), dq.size())
+
     @defer.inlineCallbacks
     def testStopSetsStopped(self):
         dq = ResizableDispatchQueue(None, 5)
